==> antigrav-1.0.tar.gz: antigrav-1.0/antigrav/scanner.py <==
"""ANTIGRAV token scanner
"""
import re
# try:
#     from _json import make_scanner as c_make_scanner
# except ImportError:
#     c_make_scanner = None
# i need to find the built in c make scanner igwuigehgehgete4

__all__ = ['make_scanner']

NUMBER_RE = re.compile(
    r'(-?(?:0|[1-9]\d*))(\.\d+)?([eE][-+]?\d+)?',
    (re.VERBOSE | re.MULTILINE | re.DOTALL)
)

def py_make_scanner(context):
    parse_object = context.parse_object
    parse_array = context.parse_array
    parse_string = context.parse_string
    strict = context.strict
    parse_float = context.parse_float
    parse_int = context.parse_int
    parse_complex = context.parse_complex
    parse_constant = context.parse_constant
    object_hook = context.object_hook
    object_pairs_hook = context.object_pairs_hook
    memo = context.memo

    def _scan_once(string, idx):
        try:
            nextchar = string[idx]
        except IndexError:
            raise StopIteration(idx) from None

        if nextchar == '"':
            return parse_string(string, idx + 1, strict)
        elif nextchar == '{':
            return parse_object((string, idx + 1), strict,
                _scan_once, object_hook, object_pairs_hook, memo)
        elif nextchar == '[':
            return parse_array((string, idx + 1), _scan_once)
        elif nextchar == 'n' and string[idx:idx + 4] == 'null':
            return None, idx + 4
        elif nextchar == 't' and string[idx:idx + 4] == 'true':
            return True, idx + 4
        elif nextchar == 'f' and string[idx:idx + 5] == 'false':
            return False, idx + 5

        m = re.compile(
            r"(?P<real>[+-]?\d+\.\d+|\d+)(?P<sign>[+-])(?P<imag>[+-]?\d+\.\d+|\d+)i",
            (re.VERBOSE | re.MULTILINE | re.DOTALL)
        ).match(string, idx)
        if m:
            real = float(m.group("real"))
            imag = float(m.group("imag")) * (-1 if m.group("sign") == "-" else 1)
            res = parse_complex(real, imag)
            return res, m.end()

        m = NUMBER_RE.match(string, idx)
        if m is not None:
            integer, frac, exp = m.groups()
            if frac or exp:
                res = parse_float(integer + (frac or '') + (exp or ''))
            else:
                res = parse_int(integer)
            return res, m.end()
        elif nextchar == 'N' and string[idx:idx + 3] == 'NaN':
            return parse_constant('NaN'), idx + 3
        elif nextchar == 'I' and string[idx:idx + 8] == 'Infinity':
            return parse_constant('Infinity'), idx + 8
        elif nextchar == '-' and string[idx:idx + 9] == '-Infinity':
            return parse_constant('-Infinity'), idx + 9
        else:
            raise StopIteration(idx)

    def scan_once(string, idx):
        try:
            return _scan_once(string, idx)
        finally:
            memo.clear()

    return scan_once
# make_scanner = c_make_scanner or py_make_scanner
make_scanner = py_make_scanner

==> antigrav-1.1.tar.gz: antigrav-1.1/antigrav/scanner.py <==
"""ANTIGRAV token scanner
"""
import re
# try:
#     from _json import make_scanner as c_make_scanner
# except ImportError:
#     c_make_scanner = None
# i need to find the built in c make scanner igwuigehgehgete4

__all__ = ['make_scanner']

NUMBER_RE = re.compile(
    r'(-?(?:0|[1-9]\d*))(\.\d+)?([eE][-+]?\d+)?',
    (re.VERBOSE | re.MULTILINE | re.DOTALL)
)

def py_make_scanner(context):
    parse_object = context.parse_object
    parse_array = context.parse_array
    parse_string = context.parse_string
    strict = context.strict
    parse_float = context.parse_float
    parse_int = context.parse_int
    parse_complex = context.parse_complex
    parse_constant = context.parse_constant
    object_hook = context.object_hook
    object_pairs_hook = context.object_pairs_hook
    memo = context.memo

    def _scan_once(string, idx):
        try:
            nextchar = string[idx]
        except IndexError:
            raise StopIteration(idx) from None

        if nextchar == '"':
            return parse_string(string, idx + 1, strict)
        elif nextchar == '{':
            return parse_object((string, idx + 1), strict,
                _scan_once, object_hook, object_pairs_hook, memo)
        elif nextchar == '[':
            return parse_array((string, idx + 1), _scan_once)
        elif nextchar == 'n' and string[idx:idx + 4] == 'null':
            return None, idx + 4
        elif nextchar == 't' and string[idx:idx + 4] == 'true':
            return True, idx + 4
        elif nextchar == 'f' and string[idx:idx + 5] == 'false':
            return False, idx + 5

        m = re.compile(
            r"(?P<real>(?:\d+|\d+\.\d+|\d+\.\d+e[+-]\d+))(?P<sign>[+-])(?P<imag>(?:\d+|\d+\.\d+|\d+\.\d+e[+-]\d+)|(?:0))i",
            (re.VERBOSE | re.MULTILINE | re.DOTALL)
        ).match(string, idx)
        if m:
            real = m.group("real")
            if real.isdigit():
                real = parse_int(real)
            else:
                real = parse_float(real)
            imag = m.group("imag")
            if imag.isdigit():
                imag = parse_int(imag)
            else:
                imag = parse_float(imag)
            imag *= (-1 if m.group("sign") == "-" else 1)
            res = parse_complex(real, imag)
            return res, m.end()

        m = NUMBER_RE.match(string, idx)
        if m is not None:
            integer, frac, exp = m.groups()
            if frac or exp:
                res = parse_float(integer + (frac or '') + (exp or ''))
            else:
                res = parse_int(integer)
            return res, m.end()
        elif nextchar == 'N' and string[idx:idx + 3] == 'NaN':
            return parse_constant('NaN'), idx + 3
        elif nextchar == 'I' and string[idx:idx + 8] == 'Infinity':
            return parse_constant('Infinity'), idx + 8
        elif nextchar == '-' and string[idx:idx + 9] == '-Infinity':
            return parse_constant('-Infinity'), idx + 9
        else:
            raise StopIteration(idx)

    def scan_once(string, idx):
        try:
            return _scan_once(string, idx)
        finally:
            memo.clear()

    return scan_once
# make_scanner = c_make_scanner or py_make_scanner
make_scanner = py_make_scanner
